@@ -4,6 +4,7 @@ import multiprocessing
 import os
 import pmb.parse.arch
 import sys
+from typing import List
 
 #
 # Exported functions
@@ -58,7 +59,16 @@ required_programs = [
     "ps",
     "tar",
 ]
-sudo = which_sudo()
+
+
+def sudo(cmd: List[str]) -> List[str]:
+    """Adapt a command to run as root."""
+    sudo = which_sudo()
+    if sudo:
+        return [sudo, *cmd]
+    else:
+        return cmd
+
 
 # Keys saved in the config file (mostly what we ask in 'pmbootstrap init')
 config_keys = [
@@ -113,7 +123,7 @@ defaults = {
     "jobs": str(multiprocessing.cpu_count() + 1),
     "kernel": "stable",
     "keymap": "",
-    "locale": "C.UTF-8",
+    "locale": "en_US.UTF-8",
     "log": "$WORK/log.txt",
     "mirror_alpine": "http://dl-cdn.alpinelinux.org/alpine/",
     # NOTE: mirrors_postmarketos variable type is supposed to be
@@ -121,11 +131,10 @@ defaults = {
     "mirrors_postmarketos": "http://mirror.postmarketos.org/postmarketos/",
     "nonfree_firmware": True,
     "nonfree_userland": False,
-    "port_distccd": "33632",
     "ssh_keys": False,
     "ssh_key_glob": "~/.ssh/id_*.pub",
     "timezone": "GMT",
-    "ui": "weston",
+    "ui": "console",
     "ui_extras": False,
     "user": "user",
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
@@ -158,26 +167,6 @@ if "NO_COLOR" in os.environ:
     for style in styles.keys():
         styles[style] = ""
 
-
-# List of available locales taken from musl-locales package; see
-# https://pkgs.alpinelinux.org/contents?name=musl-locales
-locales = [
-    "C.UTF-8",
-    "ch_DE.UTF-8",
-    "de_CH.UTF-8",
-    "de_DE.UTF-8",
-    "en_GB.UTF-8",
-    "en_US.UTF-8",
-    "es_ES.UTF-8",
-    "fr_FR.UTF-8",
-    "it_IT.UTF-8",
-    "nb_NO.UTF-8",
-    "nl_NL.UTF-8",
-    "pt_BR.UTF-8",
-    "ru_RU.UTF-8",
-    "sv_SE.UTF-8"
-]
-
 # Supported filesystems and their fstools packages
 filesystems = {"btrfs": "btrfs-progs",
                "ext2": "e2fsprogs",
@@ -781,7 +770,6 @@ deviceinfo_attributes = [
     "codename",
     "year",
     "dtb",
-    "modules_initfs",
     "arch",
 
     # device
@@ -801,13 +789,22 @@ deviceinfo_attributes = [
     # flash
     "flash_heimdall_partition_kernel",
     "flash_heimdall_partition_initfs",
-    "flash_heimdall_partition_system",
+    "flash_heimdall_partition_rootfs",
+    "flash_heimdall_partition_system", # deprecated
     "flash_heimdall_partition_vbmeta",
     "flash_heimdall_partition_dtbo",
     "flash_fastboot_partition_kernel",
-    "flash_fastboot_partition_system",
+    "flash_fastboot_partition_rootfs",
+    "flash_fastboot_partition_system", # deprecated
     "flash_fastboot_partition_vbmeta",
     "flash_fastboot_partition_dtbo",
+    "flash_rk_partition_kernel",
+    "flash_rk_partition_rootfs",
+    "flash_rk_partition_system", # deprecated
+    "flash_mtkclient_partition_kernel",
+    "flash_mtkclient_partition_rootfs",
+    "flash_mtkclient_partition_vbmeta",
+    "flash_mtkclient_partition_dtbo",
     "generate_legacy_uboot_initfs",
     "kernel_cmdline",
     "generate_bootimg",
@@ -845,7 +842,7 @@ deviceinfo_attributes = [
     "keymaps",
 ]
 
-# Valid types for the 'chassis' atribute in deviceinfo
+# Valid types for the 'chassis' attribute in deviceinfo
 # See https://www.freedesktop.org/software/systemd/man/machine-info.html
 deviceinfo_chassis_types = [
     "desktop",
@@ -887,6 +884,7 @@ flash_methods = [
     "0xffff",
     "fastboot",
     "heimdall",
+    "mtkclient",
     "none",
     "rkdeveloptool",
     "uuu",
@@ -911,7 +909,7 @@ $IMAGE: Path to the combined boot/rootfs image
 $IMAGE_SPLIT_BOOT: Path to the (split) boot image
 $IMAGE_SPLIT_ROOT: Path to the (split) rootfs image
 $PARTITION_KERNEL: Partition to flash the kernel/boot.img to
-$PARTITION_SYSTEM: Partition to flash the rootfs to
+$PARTITION_ROOTFS: Partition to flash the rootfs to
 
 Fastboot specific: $KERNEL_CMDLINE
 Heimdall specific: $PARTITION_INITFS
@@ -922,7 +920,7 @@ flashers = {
         "depends": [],  # pmaports.cfg: supported_fastboot_depends
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
-            "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
+            "flash_rootfs": [["fastboot", "flash", "$PARTITION_ROOTFS",
                               "$IMAGE"]],
             "flash_kernel": [["fastboot", "flash", "$PARTITION_KERNEL",
                               "$BOOT/boot.img$FLAVOR"]],
@@ -953,7 +951,7 @@ flashers = {
         "depends": ["android-tools"],
         "actions": {
             "list_devices": [["fastboot", "devices", "-l"]],
-            "flash_rootfs": [["fastboot", "flash", "$PARTITION_SYSTEM",
+            "flash_rootfs": [["fastboot", "flash", "$PARTITION_ROOTFS",
                               "$IMAGE_SPLIT_ROOT"]],
             "flash_kernel": [["fastboot", "flash", "$PARTITION_KERNEL",
                               "$IMAGE_SPLIT_BOOT"]],
@@ -971,7 +969,7 @@ flashers = {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
                 ["heimdall_wait_for_device.sh"],
-                ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
+                ["heimdall", "flash", "--$PARTITION_ROOTFS", "$IMAGE"]],
             "flash_kernel": [["heimdall_flash_kernel.sh",
                               "$BOOT/initramfs$FLAVOR", "$PARTITION_INITFS",
                               "$BOOT/vmlinuz$FLAVOR$DTB",
@@ -986,7 +984,7 @@ flashers = {
             "list_devices": [["heimdall", "detect"]],
             "flash_rootfs": [
                 ["heimdall_wait_for_device.sh"],
-                ["heimdall", "flash", "--$PARTITION_SYSTEM", "$IMAGE"]],
+                ["heimdall", "flash", "--$PARTITION_ROOTFS", "$IMAGE"]],
             "flash_kernel": [
                 ["heimdall_wait_for_device.sh"],
                 ["heimdall", "flash", "--$PARTITION_KERNEL",
@@ -1029,7 +1027,7 @@ flashers = {
         "actions": {
             "list_devices": [["rkdeveloptool", "list"]],
             "flash_rootfs": [
-                ["rkdeveloptool", "write-partition", "$PARTITION_SYSTEM",
+                ["rkdeveloptool", "write-partition", "$PARTITION_ROOTFS",
                     "$IMAGE_SPLIT_ROOT"]
             ],
             "flash_kernel": [
@@ -1037,6 +1035,27 @@ flashers = {
                     "$IMAGE_SPLIT_BOOT"]
             ],
         },
+    },
+    "mtkclient": {
+        "depends": ["mtkclient"],
+        "actions": {
+            "flash_rootfs": [["mtk", "w", "$PARTITION_ROOTFS",
+                              "$IMAGE"]],
+            "flash_kernel": [["mtk", "w", "$PARTITION_KERNEL",
+                              "$BOOT/boot.img$FLAVOR"]],
+            "flash_vbmeta": [
+                # Generate vbmeta image with "disable verification" flag
+                ["avbtool", "make_vbmeta_image", "--flags", "2",
+                    "--padding_size", "$FLASH_PAGESIZE",
+                    "--output", "/vbmeta.img"],
+                ["mtk", "w", "$PARTITION_VBMETA", "/vbmeta.img"],
+                ["rm", "-f", "/vbmeta.img"]
+            ],
+            "flash_dtbo": [["mtk", "w", "$PARTITION_DTBO",
+                            "$BOOT/dtbo.img"]],
+            "flash_lk2nd": [["mtk", "w", "$PARTITION_KERNEL",
+                             "$BOOT/lk2nd.img"]]
+        }
     }
 }
 
