@@ -354,6 +354,26 @@ def setup_keymap(args):
         logging.info("NOTE: No valid keymap specified for device")
 
 
+def setup_timezone(args):
+    suffix = f"rootfs_{args.device}"
+
+    arch = args.deviceinfo["arch"]
+    alpine_conf = pmb.helpers.package.get(args, "alpine-conf", arch)
+    version = alpine_conf["version"].split("-r")[0]
+
+    setup_tz_cmd = ["setup-timezone"]
+    # setup-timezone will, by default, copy the timezone to /etc/zoneinfo
+    # and disregard tzdata, to save space. If we actually have tzdata
+    # installed, make sure that setup-timezone makes use of it, since
+    # there's no space to be saved.
+    if "tzdata" in pmb.chroot.apk.installed(args, suffix):
+        setup_tz_cmd += ["-i"]
+    if not pmb.parse.version.check_string(version, ">=3.14.0"):
+        setup_tz_cmd += ["-z"]
+    setup_tz_cmd += [args.timezone]
+    pmb.chroot.root(args, setup_tz_cmd, suffix)
+
+
 def setup_hostname(args):
     """
     Set the hostname and update localhost address in /etc/hosts
@@ -586,7 +606,7 @@ def write_cgpt_kpart(args, layout, suffix):
     :param layout: partition layout from get_partition_layout()
     :param suffix: of the chroot, which holds the image file to be flashed
     """
-    if not args.deviceinfo["cgpt_kpart"]:
+    if not args.deviceinfo["cgpt_kpart"] or not args.install_cgpt:
         return
 
     device_rootfs = mount_device_rootfs(args, suffix)
@@ -674,6 +694,74 @@ def get_partition_layout(reserve, kernel):
     return ret
 
 
+def get_uuid(args, partition):
+    """
+    Get UUID of a partition
+
+    :param partition: block device for getting UUID from
+    """
+    return pmb.chroot.root(
+        args,
+        [
+            "blkid",
+            "-s", "UUID",
+            "-o", "value",
+            partition,
+        ],
+        output_return=True
+    ).rstrip()
+
+
+def create_crypttab(args, layout, suffix):
+    """
+    Create /etc/crypttab config
+
+    :param layout: partition layout from get_partition_layout()
+    :param suffix: of the chroot, which crypttab will be created to
+    """
+
+    luks_uuid = get_uuid(args, f"/dev/installp{layout['root']}")
+
+    crypttab = f"root UUID={luks_uuid} none luks\n"
+
+    open(f"{args.work}/chroot_{suffix}/tmp/crypttab", "w").write(crypttab)
+    pmb.chroot.root(args, ["mv", "/tmp/crypttab", "/etc/crypttab"], suffix)
+
+
+def create_fstab(args, layout, suffix):
+    """
+    Create /etc/fstab config
+
+    :param layout: partition layout from get_partition_layout()
+    :param suffix: of the chroot, which fstab will be created to
+    """
+
+    # Do not install fstab into target rootfs when using on-device
+    # installer. Provide fstab only to installer suffix
+    if args.on_device_installer and "rootfs_" in suffix:
+        return
+
+    boot_dev = f"/dev/installp{layout['boot']}"
+    root_dev = f"/dev/installp{layout['root']}"
+
+    boot_mount_point = f"UUID={get_uuid(args, boot_dev)}"
+    root_mount_point = "/dev/mapper/root" if args.full_disk_encryption \
+        else f"UUID={get_uuid(args, root_dev)}"
+
+    boot_filesystem = args.deviceinfo["boot_filesystem"] or "ext2"
+    root_filesystem = pmb.install.get_root_filesystem(args)
+
+    fstab = f"""
+# <file system> <mount point> <type> <options> <dump> <pass>
+{root_mount_point} / {root_filesystem} defaults 0 0
+{boot_mount_point} /boot {boot_filesystem} defaults 0 0
+""".lstrip()
+
+    with open(f"{args.work}/chroot_{suffix}/tmp/fstab", "w") as f:
+        f.write(fstab)
+    pmb.chroot.root(args, ["mv", "/tmp/fstab", "/etc/fstab"], suffix)
+
+
 def install_system_image(args, size_reserve, suffix, step, steps,
                          boot_label="pmOS_boot", root_label="pmOS_root",
                          split=False, sdcard=None):
@@ -692,12 +780,13 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     logging.info(f"*** ({step}/{steps}) PREPARE INSTALL BLOCKDEVICE ***")
     pmb.chroot.shutdown(args, True)
     (size_boot, size_root) = get_subpartitions_size(args, suffix)
-    layout = get_partition_layout(size_reserve, args.deviceinfo["cgpt_kpart"])
+    layout = get_partition_layout(size_reserve, args.deviceinfo["cgpt_kpart"] \
+             and args.install_cgpt)
     if not args.rsync:
         pmb.install.blockdevice.create(args, size_boot, size_root,
                                        size_reserve, split, sdcard)
         if not split:
-            if args.deviceinfo["cgpt_kpart"]:
+            if args.deviceinfo["cgpt_kpart"] and args.install_cgpt:
                 pmb.install.partition_cgpt(
                     args, layout, size_boot, size_reserve)
             else:
@@ -707,6 +796,21 @@ def install_system_image(args, size_reserve, suffix, step, steps,
 
     pmb.install.format(args, layout, boot_label, root_label, sdcard)
 
+    # Create /etc/fstab and /etc/crypttab
+    logging.info("(native) create /etc/fstab")
+    create_fstab(args, layout, suffix)
+    if args.full_disk_encryption:
+        logging.info("(native) create /etc/crypttab")
+        create_crypttab(args, layout, suffix)
+
+    # Run mkinitfs to pass UUIDs to cmdline
+    logging.info(f"({suffix}) mkinitfs")
+    pmb.chroot.root(args, ["mkinitfs"], suffix)
+
+    # Clean up after running mkinitfs in chroot
+    pmb.helpers.mount.umount_all(args, f"{args.work}/chroot_{suffix}")
+    pmb.helpers.run.root(args, ["rm", f"{args.work}/chroot_{suffix}/in-pmbootstrap"])
+
     # Just copy all the files
     logging.info(f"*** ({step + 1}/{steps}) FILL INSTALL BLOCKDEVICE ***")
     copy_files_from_chroot(args, suffix)
@@ -1021,14 +1125,7 @@ def create_device_rootfs(args, step, steps):
     setup_keymap(args)
 
     # Set timezone
-    arch = args.deviceinfo["arch"]
-    package = pmb.helpers.package.get(args, "alpine-conf", arch)
-    version = package["version"].split("-r")[0]
-
-    if not pmb.parse.version.check_string(version, ">=3.14.0"):
-        pmb.chroot.root(args, ["setup-timezone", "-z", args.timezone], suffix)
-    else:
-        pmb.chroot.root(args, ["setup-timezone", args.timezone], suffix)
+    setup_timezone(args)
 
     # Set locale
     if locale_is_set:
