@@ -1,4 +1,4 @@
-# Copyright 2022 Oliver Smith
+# Copyright 2023 Oliver Smith
 # SPDX-License-Identifier: GPL-3.0-or-later
 import fnmatch
 import platform
@@ -12,8 +12,9 @@ def alpine_native():
         "i686": "x86",
         "x86_64": "x86_64",
         "aarch64": "aarch64",
+        "arm64": "aarch64",
         "armv6l": "armhf",
-        "armv7l": "armv7"
+        "armv7l": "armv7",
     }
     if machine in mapping:
         return mapping[machine]
@@ -63,7 +64,8 @@ def alpine_to_kernel(arch):
         "aarch64*": "arm64",
         "arm*": "arm",
         "ppc*": "powerpc",
-        "s390*": "s390"
+        "s390*": "s390",
+        "riscv64*": "riscv",
     }
     for pattern, arch_kernel in mapping.items():
         if fnmatch.fnmatch(arch, pattern):
