@@ -79,6 +79,8 @@ def arguments_install(subparser):
                      " installation - will be handled in PLAIN TEXT during"
                      " install and may be logged to the logfile, do not use an"
                      " important password!")
+    ret.add_argument("--no-cgpt", help="do not use cgpt partition table",
+                     dest="install_cgpt", action="store_false", default=True)
 
     # Image type
     group_desc = ret.add_argument_group(
@@ -250,13 +252,13 @@ def arguments_flasher(subparser):
                              " default boot image partition ")
 
     # Flash rootfs
-    flash_rootfs = sub.add_parser("flash_rootfs", aliases=["flash_system"],
+    flash_rootfs = sub.add_parser("flash_rootfs",
                                   help="flash the rootfs to a partition on the"
                                   " device (partition layout does not get"
                                   " changed)")
     flash_rootfs.add_argument("--partition", default=None,
                               help="partition to flash the rootfs to (defaults"
-                                   " to deviceinfo_flash_*_partition_system,"
+                                   " to deviceinfo_flash_*_partition_rootfs,"
                                    " 'userdata' on Android may have more"
                                    " space)")
 
@@ -611,7 +613,6 @@ def arguments():
     parser.add_argument("--config-channels",
                         help="path to channels.cfg (which is by default"
                              " read from pmaports.git, origin/master branch)")
-    parser.add_argument("-d", "--port-distccd", dest="port_distccd")
     parser.add_argument("-mp", "--mirror-pmOS", dest="mirrors_postmarketos",
                         help="postmarketOS mirror, disable with: -mp='',"
                              " specify multiple with: -mp='one' -mp='two',"
@@ -652,16 +653,6 @@ def arguments():
     # Compiler
     parser.add_argument("--no-ccache", action="store_false",
                         dest="ccache", help="do not cache the compiled output")
-    parser.add_argument("--no-crossdirect", action="store_true",
-                        help="Don't use the new, faster 'crossdirect' method,"
-                             " use the old 'distcc-sshd' method instead. Use"
-                             " if crossdirect broke something. This option"
-                             " and the legacy 'distcc-sshd' code will be"
-                             " removed soon if no problems turn up.")
-    parser.add_argument("--distcc-nofallback", action="store_false",
-                        help="when using the cross compiler via distcc fails,"
-                             "do not fall back to compiling slowly with QEMU",
-                        dest="distcc_fallback")
     parser.add_argument("--no-cross", action="store_false", dest="cross",
                         help="disable cross compiler, build only with QEMU and"
                              " gcc (slow!)")
@@ -705,14 +696,10 @@ def arguments():
 
     # Action: log
     log = sub.add_parser("log", help="follow the pmbootstrap logfile")
-    log_distccd = sub.add_parser(
-        "log_distccd",
-        help="follow the distccd logfile")
-    for action in [log, log_distccd]:
-        action.add_argument("-n", "--lines", default="60",
-                            help="count of initial output lines")
-        action.add_argument("-c", "--clear", help="clear the log",
-                            action="store_true", dest="clear_log")
+    log.add_argument("-n", "--lines", default="60",
+                     help="count of initial output lines")
+    log.add_argument("-c", "--clear", help="clear the log",
+                     action="store_true", dest="clear_log")
 
     # Action: zap
     zap = sub.add_parser("zap", help="safely delete chroot folders")
